@@ -14,7 +14,7 @@
 #'    conditional model, the zero-inflated part of the model, the dispersion
 #'    term or the instrumental variables be returned? Applies to models
 #'    with zero-inflated and/or dispersion formula, or to models with instrumental
-#'    variable (so called fixed-effects regressioms). May be abbreviated.
+#'    variable (so called fixed-effects regressions). May be abbreviated.
 #' @param flatten Logical, if \code{TRUE}, the values are returned
 #'    as character vector, not as list.
 #'
@@ -29,6 +29,7 @@
 #'      \item \code{zero_inflated_random}, the "random effects" terms from the zero-inflation component of the model
 #'      \item \code{dispersion}, the dispersion terms
 #'      \item \code{instruments}, for fixed-effects regressions like \code{ivreg}, \code{felm} or \code{plm}, the instrumental variables
+#'      \item \code{correlation}, for models with correlation-component like \code{gls}, the variables used to describe the correlation structure
 #'    }
 #'
 #' @examples
@@ -36,13 +37,13 @@
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' find_predictors(m)
 #' @export
-find_predictors <- function(x, effects = c("fixed", "random", "all"), component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments"), flatten = FALSE) {
+find_predictors <- function(x, effects = c("fixed", "random", "all"), component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments", "correlation"), flatten = FALSE) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
   f <- find_formula(x)
   is_mv <- is_multivariate(f)
-  elements <- get_elements(effects, component)
+  elements <- .get_elements(effects, component)
 
   # filter formulas, depending on requested effects and components
   if (is_mv) {
@@ -71,7 +72,7 @@ find_predictors <- function(x, effects = c("fixed", "random", "all"), component
 
 
 return_vars <- function(f) {
-  l <- compact_list(lapply(names(f), function(i) {
+  l <- lapply(names(f), function(i) {
     if (i %in% c("random", "zero_inflated_random")) {
       unique(paste(unlist(f[[i]])))
     } else if (is.numeric(f[[i]])) {
@@ -85,9 +86,14 @@ return_vars <- function(f) {
         unique(all.vars(f[[i]]))
       }
     }
-  }))
+  })
 
-  names(l) <- names(f)
+  empty_elements <- sapply(l, is_empty_object)
+  l <- compact_list(l)
+
+  # remove constants
+  l <- lapply(l, setdiff, "pi")
+  names(l) <- names(f)[!empty_elements]
 
   l
 }
