@@ -59,6 +59,13 @@ link_function.multinom <- function(x, ...) {
 }
 
 
+#' @export
+link_function.gamlss <- function(x, ...) {
+  faminfo <- get(x$family[1], asNamespace("gamlss"))()
+  faminfo$mu.linkfun
+}
+
+
 #' @export
 link_function.gamm <- function(x, ...) {
   x <- x$gam
@@ -116,6 +123,18 @@ link_function.gmnl <- function(x, ...) {
 }
 
 
+#' @export
+link_function.logistf <- function(x, ...) {
+  stats::make.link("logit")$linkfun
+}
+
+
+#' @export
+link_function.lrm <- function(x, ...) {
+  stats::make.link("logit")$linkfun
+}
+
+
 #' @export
 link_function.mlogit <- function(x, ...) {
   stats::make.link("logit")$linkfun
@@ -146,6 +165,12 @@ link_function.betareg <- function(x, ...) {
 }
 
 
+#' @export
+link_function.mixed <- function(x, ...) {
+  stats::gaussian(link = "identity")$linkfun
+}
+
+
 #' @export
 link_function.truncreg <- function(x, ...) {
   stats::gaussian(link = "identity")$linkfun
@@ -164,6 +189,60 @@ link_function.lme <- function(x, ...) {
 }
 
 
+#' @export
+link_function.rq <- function(x, ...) {
+  stats::gaussian(link = "identity")$linkfun
+}
+
+
+#' @export
+link_function.crq <- function(x, ...) {
+  stats::gaussian(link = "identity")$linkfun
+}
+
+
+#' @export
+link_function.tobit <- function(x, ...) {
+  .make_tobit_family(x)$linkfun
+}
+
+
+#' @export
+link_function.crch <- function(x, ...) {
+  .make_tobit_family(x)$linkfun
+}
+
+
+#' @export
+link_function.survreg <- function(x, ...) {
+  .make_tobit_family(x)$linkfun
+}
+
+
+#' @export
+link_function.lmRob <- function(x, ...) {
+  stats::gaussian(link = "identity")$linkfun
+}
+
+
+#' @export
+link_function.lmrob <- function(x, ...) {
+  stats::gaussian(link = "identity")$linkfun
+}
+
+
+#' @export
+link_function.lm_robust <- function(x, ...) {
+  stats::gaussian(link = "identity")$linkfun
+}
+
+
+#' @export
+link_function.iv_robust <- function(x, ...) {
+  stats::gaussian(link = "identity")$linkfun
+}
+
+
 #' @export
 link_function.aovlist <- function(x, ...) {
   stats::gaussian(link = "identity")$linkfun
