@@ -19,11 +19,16 @@
 #'      \item \code{is_negbin}: family is negative binomial
 #'      \item \code{is_count}: model is a count model (i.e. family is either poisson or negative binomial)
 #'      \item \code{is_beta}: family is beta
+#'      \item \code{is_exponential}: family is exponential (e.g. Gamma or Weibull)
 #'      \item \code{is_logit}: model has logit link
+#'      \item \code{is_progit}: model has probit link
 #'      \item \code{is_linear}: family is gaussian
+#'      \item \code{is_tweedie}: family is tweedie
 #'      \item \code{is_ordinal}: family is ordinal or cumulative link
 #'      \item \code{is_categorical}: family is categorical link
+#'      \item \code{is_censored}: model is a censored model
 #'      \item \code{is_zeroinf}: model has zero-inflation component
+#'      \item \code{is_zero_inflated}: alias for \code{is_zeroinf}
 #'      \item \code{is_mixed}: model is a mixed effects model (with random effects)
 #'      \item \code{is_multivariate}: model is a multivariate response model (currently only works for \emph{brmsfit} objects)
 #'      \item \code{is_trial}: model response contains additional information about the trials
@@ -68,16 +73,15 @@ model_info.default <- function(x, ...) {
     class(x) <- c(class(x), c("glm", "lm"))
   }
 
-  faminfo <- tryCatch({
-    if (inherits(x, c("Zelig-relogit"))) {
-      stats::binomial(link = "logit")
-    } else {
-      stats::family(x)
-    }
-  },
-  error = function(x) {
-    NULL
-  }
+  faminfo <- tryCatch(
+    {
+      if (inherits(x, c("Zelig-relogit"))) {
+        stats::binomial(link = "logit")
+      } else {
+        stats::family(x)
+      }
+    },
+    error = function(x) { NULL }
   )
 
   if (!is.null(faminfo)) {
@@ -90,9 +94,6 @@ model_info.default <- function(x, ...) {
     )
   } else {
     warning("Could not access model information.", call. = FALSE)
-    if (inherits(faminfo, c("error", "simpleError"))) {
-      cat(sprintf("* Reason: %s\n", deparse(faminfo[[1]], width.cutoff = 500)))
-    }
   }
 }
 
@@ -131,6 +132,48 @@ model_info.MixMod <- function(x, ...) {
 }
 
 
+#' @export
+model_info.tobit <- function(x, ...) {
+  faminfo <- .make_tobit_family(x)
+
+  make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
+#' @export
+model_info.crch <- function(x, ...) {
+  faminfo <- .make_tobit_family(x)
+
+  make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
+#' @export
+model_info.survreg <- function(x, ...) {
+  faminfo <- .make_tobit_family(x)
+
+  make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
 #' @export
 model_info.htest <- function(x, ...) {
   make_family(x, ...)
@@ -143,6 +186,30 @@ model_info.lme <- function(x, ...) {
 }
 
 
+#' @export
+model_info.rq <- function(x, ...) {
+  make_family(x, ...)
+}
+
+
+#' @export
+model_info.crq <- function(x, ...) {
+  make_family(x, ...)
+}
+
+
+#' @export
+model_info.rqss <- function(x, ...) {
+  make_family(x, ...)
+}
+
+
+#' @export
+model_info.mixed <- function(x, ...) {
+  make_family(x, ...)
+}
+
+
 #' @export
 model_info.plm <- function(x, ...) {
   make_family(x, ...)
@@ -167,6 +234,12 @@ model_info.lmRob <- function(x, ...) {
 }
 
 
+#' @export
+model_info.lmrob <- function(x, ...) {
+  make_family(x, ...)
+}
+
+
 #' @export
 model_info.gam <- function(x, ...) {
   if (!inherits(x, c("glm", "lm"))) {
@@ -307,6 +380,12 @@ model_info.lm_robust <- function(x, ...) {
 }
 
 
+#' @export
+model_info.iv_robust <- function(x, ...) {
+  make_family(x, ...)
+}
+
+
 #' @export
 model_info.felm <- function(x, ...) {
   make_family(x, ...)
@@ -406,6 +485,19 @@ model_info.multinom <- function(x, ...) {
 }
 
 
+#' @export
+model_info.gamlss <- function(x, ...) {
+  faminfo <- get(x$family[1], asNamespace("gamlss"))()
+  make_family(
+    x = x,
+    fitfam = faminfo$family[2],
+    logit.link = faminfo$mu.link == "logit",
+    link.fun = faminfo$mu.link,
+    ...
+  )
+}
+
+
 #' @export
 model_info.clm2 <- function(x, ...) {
   faminfo <- stats::binomial(link = get_ordinal_link(x))
@@ -561,14 +653,20 @@ make_family <- function(x, fitfam = "gaussian", zero.inf = FALSE, logit.link = F
 
   beta_fam <- inherits(x, "betareg") | fitfam %in% c("beta")
 
-  linear_model <- !binom_fam & !poisson_fam & !neg_bin_fam & !logit.link
+  exponential_fam <- fitfam %in% c("Gamma", "weibull")
+
+  linear_model <- (!binom_fam & !exponential_fam & !poisson_fam & !neg_bin_fam & !logit.link) ||
+    fitfam %in% c("Student's-t", "t Family") || grepl("(\\st)$", fitfam)
+
+  tweedie_model <- linear_model && grepl("tweedie", fitfam, fixed = TRUE)
 
   zero.inf <- zero.inf | fitfam == "ziplss" |
     grepl("\\Qzero_inflated\\E", fitfam, ignore.case = TRUE) |
     grepl("\\Qzero-inflated\\E", fitfam, ignore.case = TRUE) |
     grepl("\\Qneg_binomial\\E", fitfam, ignore.case = TRUE) |
     grepl("\\Qhurdle\\E", fitfam, ignore.case = TRUE) |
-    grepl("^(zt|zi|za|hu)", fitfam, perl = TRUE)
+    grepl("^(zt|zi|za|hu)", fitfam, perl = TRUE) |
+    grepl("^truncated", fitfam, perl = TRUE)
 
   is.ordinal <-
     inherits(x, c("polr", "clm", "clm2", "clmm", "gmnl", "mlogit", "multinom")) |
@@ -636,16 +734,20 @@ make_family <- function(x, fitfam = "gaussian", zero.inf = FALSE, logit.link = F
     is_poisson = poisson_fam,
     is_negbin = neg_bin_fam,
     is_beta = beta_fam,
+    is_exponential = exponential_fam,
     is_logit = logit.link,
     is_probit = link.fun == "probit",
+    is_censored = inherits(x, c("tobit", "crch")),
     is_linear = linear_model,
+    is_tweedie = tweedie_model,
     is_zeroinf = zero.inf,
+    is_zero_inflated = zero.inf,
     is_ordinal = is.ordinal,
     is_categorical = is.categorical,
     is_mixed = !is.null(find_random(x)),
     is_multivariate = multi.var,
     is_trial = is.trial,
-    is_bayesian = inherits(x, c("brmsfit", "stanfit", "stanreg", "stanmvreg")),
+    is_bayesian = inherits(x, c("brmsfit", "stanfit", "stanreg", "stanmvreg", "bmerMod")),
     is_anova = inherits(x, c("aov", "aovlist")),
     is_ttest = is_ttest,
     is_correlation = is_correlation,
@@ -664,3 +766,21 @@ get_ordinal_link <- function(x) {
     x$link
   )
 }
+
+
+#' @importFrom stats gaussian binomial Gamma
+.make_tobit_family <- function(x) {
+  f <- switch(
+    x$dist,
+    gaussian = stats::gaussian("identity"),
+    logistic = stats::binomial("logit"),
+    loglogistic = stats::binomial("log"),
+    lognormal = stats::gaussian("log"),
+    exponential = ,
+    weibull = stats::Gamma("log"),
+    stats::gaussian("identity")
+  )
+
+  if (x$dist == "weibull") f$family <- "weibull"
+  f
+}
