@@ -2,7 +2,10 @@ if (require("testthat") && require("insight") && require("betareg")) {
   context("insight, model_info")
 
   data("GasolineYield")
+  data("FoodExpenditure")
+
   m1 <- betareg(yield ~ batch + temp, data = GasolineYield)
+  m2 <- betareg(I(food/income) ~ income + persons, data = FoodExpenditure)
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_beta)
@@ -16,10 +19,13 @@ if (require("testthat") && require("insight") && require("betareg")) {
 
   test_that("find_response", {
     expect_identical(find_response(m1), "yield")
+    expect_identical(find_response(m2), "I(food/income)")
+    expect_identical(find_response(m2, combine = FALSE), c("food", "income"))
   })
 
   test_that("get_response", {
     expect_equal(get_response(m1), GasolineYield$yield)
+    expect_equal(get_response(m2), FoodExpenditure[, c("food", "income")])
   })
 
   test_that("link_inverse", {
@@ -29,6 +35,8 @@ if (require("testthat") && require("insight") && require("betareg")) {
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 32)
     expect_equal(colnames(get_data(m1)), c("yield", "batch", "temp"))
+    expect_equal(nrow(get_data(m2)), 38)
+    expect_equal(colnames(get_data(m2)), c("I(food/income)", "income", "persons", "food", "income.1"))
   })
 
   test_that("find_formula", {
@@ -37,11 +45,16 @@ if (require("testthat") && require("insight") && require("betareg")) {
       find_formula(m1),
       list(conditional = as.formula("yield ~ batch + temp"))
     )
+    expect_equal(
+      find_formula(m2),
+      list(conditional = as.formula("I(food/income) ~ income + persons"))
+    )
   })
 
   test_that("find_terms", {
     expect_equal(find_terms(m1), list(response = "yield", conditional = c("batch", "temp")))
     expect_equal(find_terms(m1, flatten = TRUE), c("yield", "batch", "temp"))
+    expect_equal(find_terms(m2, flatten = TRUE), c("food", "income", "persons"))
   })
 
   test_that("n_obs", {
@@ -66,4 +79,14 @@ if (require("testthat") && require("insight") && require("betareg")) {
     expect_equal(nrow(get_parameters(m1)), 12)
     expect_equal(get_parameters(m1)$parameter, c("(Intercept)", "batch1", "batch2", "batch3", "batch4", "batch5", "batch6", "batch7", "batch8", "batch9", "temp", "(phi)"))
   })
+
+  test_that("find_variables", {
+    expect_equal(
+      find_variables(m2),
+      list(
+        response = "I(food/income)",
+        conditional = c("income", "persons")
+      )
+    )
+  })
 }
