@@ -83,4 +83,8 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
   test_that("is_multivariate", {
     expect_false(is_multivariate(m1))
   })
+
+  test_that("find_algorithm", {
+    expect_equal(find_algorithm(m1), list(algorithm = "ML"))
+  })
 }
