@@ -50,7 +50,7 @@ if (require("testthat") && require("insight") && require("nlme") && require("lme
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 180)
     expect_equal(colnames(get_data(m1)), c("Reaction", "Days", "Subject"))
-    expect_equal(colnames(get_data(m2)), c("distance", "age", "Subject", "Sex"))
+    expect_equal(colnames(get_data(m2)), c("distance", "age", "Sex"))
   })
 
   test_that("find_formula", {
@@ -104,4 +104,28 @@ if (require("testthat") && require("insight") && require("nlme") && require("lme
       )
     )
   })
+
+  test_that("find_algorithm", {
+    expect_equal(find_algorithm(m1), list(
+      algorithm = "REML", optimizer = "nlminb"
+    ))
+  })
+
+  test_that("get_variance", {
+
+    skip_on_cran()
+
+    expect_equal(get_variance(m1), list(
+      var.fixed = 908.95336262308865116211,
+      var.random = 1698.06593646939654718153,
+      var.residual = 654.94240352794997761521,
+      var.distribution = 654.94240352794997761521,
+      var.dispersion = 0,
+      var.intercept = c(Subject = 612.07951112963326067984),
+      var.slope = c(Subject.Days = 35.07130179308116169068),
+      cor.slope_intercept = 0.06600000000000000311
+    ),
+    tolerance = 1e-4)
+  })
+
 }
