@@ -3,6 +3,7 @@ if (require("testthat") && require("insight") && require("lme4")) {
 
   data(sleepstudy)
 
+  set.seed(123)
   sleepstudy$mygrp <- sample(1:5, size = 180, replace = TRUE)
   sleepstudy$mysubgrp <- NA
   for (i in 1:5) {
@@ -167,4 +168,56 @@ if (require("testthat") && require("insight") && require("lme4")) {
     expect_false(is_multivariate(m1))
     expect_false(is_multivariate(m2))
   })
+
+  test_that("get_variance", {
+
+    skip_on_cran()
+
+    expect_equal(get_variance(m1), list(
+      var.fixed = 908.95336262316459396970,
+      var.random = 1698.23306388298283309268,
+      var.residual = 654.94079585243218843971,
+      var.distribution = 654.94079585243218843971,
+      var.dispersion = 0,
+      var.intercept = c(Subject = 611.89760710463770010392),
+      var.slope = c(Subject.Days = 35.08106944030500073950),
+      cor.slope_intercept = c(Subject = 0.06561803142425107205)
+    ),
+    tolerance = 1e-4)
+
+    expect_equal(get_variance_fixed(m1), c(var.fixed = 908.95336262316459396970), tolerance = 1e-4)
+    expect_equal(get_variance_random(m1), c(var.random = 1698.23306388298283309268), tolerance = 1e-4)
+    expect_equal(get_variance_residual(m1), c(var.residual = 654.94079585243218843971), tolerance = 1e-4)
+    expect_equal(get_variance_distribution(m1), c(var.distribution = 654.94079585243218843971), tolerance = 1e-4)
+    expect_equal(get_variance_dispersion(m1), c(var.dispersion = 0), tolerance = 1e-4)
+
+    expect_equal(get_variance_intercept(m1), c(var.intercept.Subject = 611.89760710463770010392), toleance = 1e-4)
+    expect_equal(get_variance_slope(m1), c(var.slope.Subject.Days = 35.08106944030500073950), toleance = 1e-4)
+    expect_equal(get_correlation_slope_intercept(m1), c(cor.slope_intercept.Subject = 0.06561803), toleance = 1e-4)
+
+    expect_equal(get_variance(m2), list(
+      var.fixed = 899.71188516552831515583,
+      var.random = 1412.32769480994716104760,
+      var.residual = 928.81331970697453925823,
+      var.distribution = 928.81331970697453925823,
+      var.dispersion = 0,
+      var.intercept = c(
+        `mysubgrp:mygrp` = 12.61789198780912713005,
+        Subject = 1376.88290392979729404033,
+        mygrp = 22.82689889233859048545
+      )
+    ),
+    tolerance = 1e-4)
+  })
+
+  test_that("find_algorithm", {
+    expect_equal(find_algorithm(m1), list(
+      algorithm = "REML", optimizer = "nloptwrap"
+    ))
+  })
+
+  test_that("find_random_slopes", {
+    expect_equal(find_random_slopes(m1), list(random = "Days"))
+    expect_null(find_random_slopes(m2))
+  })
 }
