@@ -93,7 +93,8 @@ if (require("testthat") && require("insight") && require("VGAM")) {
     expect_equal(
       find_parameters(m1),
       list(
-        conditional = c("(Intercept)", "vitluc", "s(altitude, df = 2)")
+        conditional = c("(Intercept)", "vitluc"),
+        smooth_terms = "s(altitude, df = 2)"
       )
     )
     expect_equal(nrow(get_parameters(m1)), 3)
@@ -102,7 +103,8 @@ if (require("testthat") && require("insight") && require("VGAM")) {
     expect_equal(
       find_parameters(m2),
       list(
-        conditional = c("(Intercept):1", "(Intercept):2", "vitluc:1", "vitluc:2", "s(altitude, df = c(2, 3)):1", "s(altitude, df = c(2, 3)):2")
+        conditional = c("(Intercept):1", "(Intercept):2", "vitluc:1", "vitluc:2"),
+        smooth_terms = c("s(altitude, df = c(2, 3)):1", "s(altitude, df = c(2, 3)):2")
       )
     )
     expect_equal(nrow(get_parameters(m2)), 6)
